span.btn span.butlink {
  padding: 0 0.5ex;
}
span.btn {
  margin: 0;
  border-radius: 20px 20px 3px 3px;
  transition-duration: 150ms;
  font-size: 80%;
  width: 80px;
  display: inline-block;
  text-align: center;
  opacity: 20%;
}
span.btn img {
  vertical-align: bottom;
}
.dark span.btn img {
  filter: invert(100%);
}
span.btn:hover {
  opacity: 90%;
  transition-duration: 300ms;
}

/* TOOLTIPS: */
.tooltip {
  position: relative;
  display: inline-block;
  z-index: 3;
}
.tooltip .tooltiptext {
  margin-top: 30px;
  margin-left: -40px;
  visibility: hidden;
  width: 120px;
  background-color: #c2cad7;
  color: rgb(37, 37, 37);
  text-align: center;
  border-radius: 6px;
  padding: 5px 0;
  /* Position the tooltip */
  position: absolute;
  opacity: 0%;
  transition-duration: 300ms;
}
.dark .tooltip .tooltiptext {
  background-color: #1b1b1c;
  color: #ddd;
}
.tooltip:hover .tooltiptext {
  visibility: visible;
  opacity: 100%;
  transition-delay: 1s;
  transition-duration: 300ms;
  margin-top: 50px;
}
div#editor.rendering {
  padding: 0 1em;
}
div#editor.editing {
  padding: 0;
}
.editor-preview-side {
  background-color: white;
}
.dark .editor-preview-side {
  background-color: #5a5a5d;
}
div.CodeMirror {
  background-color: #e1e5eb;
  color: rgb(37, 37, 37);
}
.dark div.CodeMirror {
  background-color: #4d4d50;
  color: #ddd;
}
.editor-toolbar {
  background-color: white !important;
}
ul.contains-task-list {
  list-style-type: none;
  padding: 0 1ex;
}
a,
a:visited {
  color: #346693;
  text-decoration: none;
}
.dark a,
.dark a:visited {
  color: #c3d8ea;
}
a:hover {
  text-decoration: underline;
}
pre {
  background: #e4e4e4;
  color: #111;
  padding: 1ex;
  border-radius: 1ex;
  overflow-x: auto;
}
abbr {
  cursor: help;
}
dt {
  font-size: 130%;
}

/* tables formatting */
table {
  border-collapse: collapse;
}
tr {
  border-bottom: solid 1px rgb(37, 37, 37);
}
td,
th {
  border-right: solid 1px rgb(37, 37, 37);
  padding: 0.5ex 1ex;
}
.dark tr {
  border-bottom: solid 1px #ddd;
}
.dark td,
.dark th {
  border-right: solid 1px #ddd;
}
td:last-child,
th:last-child {
  border-right: none;
}
tbody > tr:last-child {
  border-bottom: none;
}
@charset "UTF-8";
.modal {
  z-index: 5;
  font-family: -apple-system, BlinkMacSystemFont, avenir next, avenir, helvetica neue, helvetica, ubuntu, roboto, noto, segoe ui, arial, sans-serif;
}
.modal__overlay {
  z-index: 4;
  position: fixed;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  background: rgba(0, 0, 0, 0.6);
  display: flex;
  justify-content: center;
  align-items: center;
}
.modal__container {
  background-color: #e1e5eb;
  padding: 30px;
  max-width: 500px;
  max-height: 100vh;
  border-radius: 4px;
  overflow-y: auto;
  box-sizing: border-box;
}
.dark .modal__container {
  background-color: rgb(52, 52, 54);
}
.modal__header {
  display: flex;
  justify-content: space-between;
  align-items: center;
}
.modal__title {
  margin-top: 0;
  margin-bottom: 0;
  font-weight: 600;
  font-size: 1.25rem;
  line-height: 1.25;
  color: #528dc2;
  box-sizing: border-box;
}
.modal__close {
  background: transparent;
  color: #528dc2;
  border: 0;
}
.modal__header .modal__close:before {
  content: "✕";
}
.modal__content {
  margin-top: 2rem;
  margin-bottom: 2rem;
  line-height: 1.5;
  color: rgb(37, 37, 37);
}
.dark .modal__content {
  color: #ddd;
}
.modal__btn {
  font-size: 0.875rem;
  padding-left: 1rem;
  padding-right: 1rem;
  padding-top: 0.5rem;
  padding-bottom: 0.5rem;
  background-color: #a4b0c2;
  color: rgba(0, 0, 0, 0.8);
  border-radius: 0.25rem;
  border-style: none;
  border-width: 0;
  cursor: pointer;
  -webkit-appearance: button;
  text-transform: none;
  overflow: visible;
  line-height: 1.15;
  margin: 0 0.5ex;
  will-change: transform;
  -moz-osx-font-smoothing: grayscale;
  -webkit-backface-visibility: hidden;
  backface-visibility: hidden;
  -webkit-transform: translateZ(0);
  transform: translateZ(0);
  transition: -webkit-transform 0.25s ease-out;
  transition: transform 0.25s ease-out;
  transition: transform 0.25s ease-out, -webkit-transform 0.25s ease-out;
}
.dark .modal__btn {
  background-color: #66666a;
}
.modal__btn:focus,
.modal__btn:hover {
  -webkit-transform: scale(1.05);
  transform: scale(1.05);
}
.dark .modal__btn-primary {
  background-color: #282828;
  color: #ddd;
}
.modal__btn-primary {
  background-color: silver;
  color: rgb(37, 37, 37);
}
@keyframes mmfadeIn {
from {
    opacity: 0;
}
to {
    opacity: 1;
}
}
@keyframes mmfadeOut {
from {
    opacity: 1;
}
to {
    opacity: 0;
}
}
@keyframes mmslideIn {
from {
    transform: translateY(15%);
}
to {
    transform: translateY(0);
}
}
@keyframes mmslideOut {
from {
    transform: translateY(0);
}
to {
    transform: translateY(-10%);
}
}
.micromodal-slide {
  display: none;
}
.micromodal-slide.is-open {
  display: block;
}
.micromodal-slide[aria-hidden=false] .modal__overlay {
  animation: mmfadeIn 0.3s cubic-bezier(0, 0, 0.2, 1);
}
.micromodal-slide[aria-hidden=false] .modal__container {
  animation: mmslideIn 0.3s cubic-bezier(0, 0, 0.2, 1);
}
.micromodal-slide[aria-hidden=true] .modal__overlay {
  animation: mmfadeOut 0.3s cubic-bezier(0, 0, 0.2, 1);
}
.micromodal-slide[aria-hidden=true] .modal__container {
  animation: mmslideOut 0.3s cubic-bezier(0, 0, 0.2, 1);
}
.micromodal-slide .modal__container,
.micromodal-slide .modal__overlay {
  will-change: transform;
}
input.userInput {
  width: 100%;
  margin: 0 0 1em 0;
}
form#upload-zone {
  min-width: 400px;
  min-height: 400px;
}
body {
  background-color: #e1e5eb;
  color: rgb(37, 37, 37);
  margin: 0;
  padding: 0;
  font-family: "Inter", "BlinkMacSystemFont", "Segoe UI", "Roboto", Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol", "Microsoft YaHei Light", sans-serif;
}
#editor img {
  max-width: 100%;
}
body.dark {
  background-color: rgb(52, 52, 54);
  color: #ddd;
}
#topbar > h1,
h1.toptitle {
  color: #528dc2;
  margin: 0;
  padding: 3px 1ex 3px 15px;
  top: 0;
  z-index: 2;
  position: fixed;
  width: 100%;
  transition-duration: 500ms;
  transition-timing-function: ease;
}
.toptitle span {
  cursor: pointer;
}
h1.toptitle.scrolled {
  box-shadow: 0px 1px 11px #100;
  transition-duration: 500ms;
  transition-timing-function: ease;
  background-color: rgba(210, 216, 225, 0.8);
}
.dark h1.toptitle.scrolled {
  background-color: rgba(39, 39, 41, 0.8);
}
#sidebar {
  box-shadow: 0px 1px 11px #100;
  transition-duration: 500ms;
  transition-timing-function: ease;
  position: fixed;
  border-radius: 0 5px 5px 0;
  margin: 0;
  padding: 0 1ex 0 0;
  width: 220px;
  overflow-y: auto;
  overflow-x: clip;
  max-height: calc(100% - 48px);
}
#sidebar.folded {
  margin-left: -250px;
}
#barbuttons {
  float: right;
}
#main {
  box-shadow: 0px 1px 11px #100;
  transition-duration: 500ms;
  transition-timing-function: ease;
  background-color: white;
  margin: 48px 1ex 1ex 240px;
  padding: 1ex;
  min-height: 400px;
  border-radius: 3px;
}
#main.fullscreen {
  margin-left: 1ex;
}
.matchSearch {
  background-color: rgb(230, 206, 162) !important;
  color: rgb(52, 52, 54) !important;
}
#main.dark {
  background-color: #5a5a5d;
}
.pageTab {
  cursor: pointer;
  width: 100%;
  background-color: silver;
  padding: 0 0.5ex 0 0.5ex;
  border: solid 1px rgba(0, 0, 0, 0.1);
}
.dark .pageTab {
  background-color: #282828;
}
.pageTab.opened {
  font-weight: bold;
}
.pageTab:hover {
  box-shadow: 0px 1px 11px #100;
  transition-duration: 0.35s;
  transition-timing-function: ease;
  font-weight: bold;
  transform: scale(1.02);
  background-color: rgba(195, 216, 234, 0.5);
  margin-left: 1%;
  border-radius: 5px;
  color: #333;
}
pre code.hljs{display:block;overflow-x:auto;padding:1em}code.hljs{padding:3px 5px}/*!
  Theme: GitHub
  Description: Light theme as seen on github.com
  Author: github.com
  Maintainer: @Hirse
  Updated: 2021-05-15

  Outdated base version: https://github.com/primer/github-syntax-light
  Current colors taken from GitHub's CSS
*/.hljs{color:#24292e;background:#fff}.hljs-doctag,.hljs-keyword,.hljs-meta .hljs-keyword,.hljs-template-tag,.hljs-template-variable,.hljs-type,.hljs-variable.language_{color:#d73a49}.hljs-title,.hljs-title.class_,.hljs-title.class_.inherited__,.hljs-title.function_{color:#6f42c1}.hljs-attr,.hljs-attribute,.hljs-literal,.hljs-meta,.hljs-number,.hljs-operator,.hljs-selector-attr,.hljs-selector-class,.hljs-selector-id,.hljs-variable{color:#005cc5}.hljs-meta .hljs-string,.hljs-regexp,.hljs-string{color:#032f62}.hljs-built_in,.hljs-symbol{color:#e36209}.hljs-code,.hljs-comment,.hljs-formula{color:#6a737d}.hljs-name,.hljs-quote,.hljs-selector-pseudo,.hljs-selector-tag{color:#22863a}.hljs-subst{color:#24292e}.hljs-section{color:#005cc5;font-weight:700}.hljs-bullet{color:#735c0f}.hljs-emphasis{color:#24292e;font-style:italic}.hljs-strong{color:#24292e;font-weight:700}.hljs-addition{color:#22863a;background-color:#f0fff4}.hljs-deletion{color:#b31d28;background-color:#ffeef0}